dbm library

Classes

BytesKey
A wrapper that compares Uint8List keys by content for use in maps.
DBM
Interface to an underlying DBM implementation.
Transaction
A transaction that accumulates changes and commits them atomically.
VersionedDBM
A DBM with delta overlay transactions and version history.

Properties

tombstone Uint8List
Sentinel value used internally to represent a deleted key in a delta.
no setter

Functions

isTombstone(Uint8List? value) bool
Check whether a value represents a tombstone (deletion marker).

Exceptions / Errors

DBMException
DBM specific exception.