BytesKey class

A wrapper that compares Uint8List keys by content for use in maps.

Constructors

BytesKey(Uint8List bytes)
Constructor.

Properties

bytes Uint8List
The underlying bytes.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override