put abstract method

Uint8List? put(
  1. Uint8List key,
  2. Uint8List value
)

Add a key, value pair to the underlying store, overwriting any existing values. Returns the old value if one existed, otherwise returns the new value.

put(utf8.encode('foo'), utf8.encode('bar')); // returns 'bar' (new)
put(utf8.encode('foo'), utf8.encode('baz')); // returns 'bar' (old)
get(utf8.encode('foo')); // returns 'baz'

Implementation

Uint8List? put(Uint8List key, Uint8List value);