flatten abstract method
void
flatten()
Merge all deltas into the base table and convert to plain format. After flattening, the file can be reopened with plain HashDBM.
Implementation
void flatten();
Merge all deltas into the base table and convert to plain format. After flattening, the file can be reopened with plain HashDBM.
void flatten();