merge abstract method

void merge({
  1. int? through,
})

Merge deltas through the given version into the base table. If through is null, merges all deltas through current.

Implementation

void merge({final int? through});