tombstone top-level property
Uint8List
get
tombstone
Sentinel value used internally to represent a deleted key in a delta.
Implementation
Uint8List get tombstone => _tombstone;
Sentinel value used internally to represent a deleted key in a delta.
Uint8List get tombstone => _tombstone;