range abstract method

Iterator<MapEntry<Uint8List, Uint8List>> range({
  1. Uint8List? start,
  2. Uint8List? end,
})

Iterate entries in sorted order from start (inclusive) to end (exclusive). If start is null, iteration begins at the first key. If end is null, iteration continues through the last key.

Implementation

Iterator<MapEntry<Uint8List, Uint8List>> range(
    {final Uint8List? start, final Uint8List? end});