libdbm library

LibDBM is a simple database implementation written in pure dart.

Classes

DBM
Interface to an underlying DBM implementation.
HashDBM
Hash-based implementation of DBM
PersistentMap<K, V>
PersistentMap used a DBM database to provide an implementation of the dart Map interface which transparently saves the Map to disk
Transaction
A transaction that accumulates changes and commits them atomically.
VersionedDBM
A DBM with delta overlay transactions and version history.
VersionedHashDBM
A VersionedDBM implementation that wraps HashDBM with delta overlay transactions and version history.

Exceptions / Errors

DBMException
DBM specific exception.