put method

  1. @override
Uint8List? put(
  1. Uint8List key,
  2. Uint8List value
)
override

Add a key, value pair to the underlying store, overwriting any existing values. Returns the old value if one existed, otherwise returns the new value.

put(utf8.encode('foo'), utf8.encode('bar')); // returns 'bar' (new)
put(utf8.encode('foo'), utf8.encode('baz')); // returns 'bar' (old)
get(utf8.encode('foo')); // returns 'baz'

Implementation

@override
Uint8List? put(final Uint8List key, final Uint8List value) {
  _guardReadonly();
  final old = get(key);
  final transaction = begin();
  transaction.put(key, value);
  transaction.commit();
  return old;
}