VersionedDBM class abstract

A DBM with delta overlay transactions and version history.

Implemented types
Implementers

Constructors

VersionedDBM()

Properties

current int
Current (latest) version number.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versions List<int>
List of available versions (base..current).
no setter

Methods

at(int version) DBM
Read-only view at a specific version.
begin() Transaction
Start a new transaction.
clear() → void
Erases all data and resets the internal structure, but does not reclaim storage.
inherited
close() → void
flush() and close the underlying file.
inherited
compact() int
Truncate trailing free blocks at end-of-file and return bytes reclaimed.
inherited
count() int
Get the number of records stored in the database as a Uint64
inherited
entries() Iterator<MapEntry<Uint8List, Uint8List>>
Iterate over all keys and values in the database
inherited
flatten() → void
Merge all deltas into the base table and convert to plain format. After flattening, the file can be reopened with plain HashDBM.
flush() → void
Flush all data to external storage.
inherited
get(Uint8List key) Uint8List?
Get a value from the database using key, or else return null
inherited
merge({int? through}) → void
Merge deltas through the given version into the base table. If through is null, merges all deltas through current.
modified() DateTime
Get the last time the database was opened or modified.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(Uint8List key, Uint8List value) Uint8List?
Add a key, value pair to the underlying store, overwriting any existing values. Returns the old value if one existed, otherwise returns the new value.
inherited
putIfAbsent(Uint8List key, Uint8List value) Uint8List
Add a key, value pair to the underlying store if not key is in the underlying store. Returns the old value if key existed, otherwise value is returned.
inherited
remove(Uint8List key) Uint8List?
Remove a value from the database using key. If the key had an associated value, return the value or else return null
inherited
size() int
Get the size, in bytes, of data stored. This is intended to track approximate data size and will differ from the size of the file itself.
inherited
toString() String
A string representation of this object.
inherited
version() int
Get the version of the underlying implementation as a 32bit integer.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited