libdbm library
LibDBM is a simple database implementation written in pure dart.
Classes
- BTreeDBM
- B+tree implementation of SortedDBM. Stores tree nodes as entries in an underlying DBM (typically HashDBM).
- DBM
- Interface to an underlying DBM implementation.
- HashDBM
- Hash-based implementation of DBM
-
PersistentMap<
K, V> - PersistentMap used a DBM database to provide an implementation of the dart Map interface which transparently saves the Map to disk
- SortedDBM
- A DBM that maintains keys in sorted order and supports range queries.
-
SortedPersistentMap<
K, V> - A PersistentMap with sorted operations backed by a SortedDBM.
- Transaction
- A transaction that accumulates changes and commits them atomically.
- VersionedDBM
- A DBM with delta overlay transactions and version history.
- VersionedHashDBM
- A VersionedDBM implementation that wraps HashDBM with delta overlay transactions and version history.
Typedefs
- KeyComparator = int Function(Uint8List a, Uint8List b)
- Comparator for raw byte keys. Returns negative if a < b, zero if equal, positive if a > b.
Exceptions / Errors
- DBMException
- DBM specific exception.